@@ -3,11 +3,7 @@
 static Object V_X_Error_Handler, V_X_Fatal_Error_Handler;
 
 /* Default error handlers of the Xlib */
-#ifdef XLIB_RELEASE_4_OR_LATER
 extern int _XDefaultIOError();   
-#else
-extern int _XIOError();
-#endif
 extern int _XDefaultError();
 
 static X_Fatal_Error (d) Display *d; {
@@ -22,11 +18,7 @@ static X_Fatal_Error (d) Display *d; {
     fun = Val (V_X_Fatal_Error_Handler);
     if (TYPE(fun) == T_Compound)
 	(void)Funcall (fun, args, 0);
-#ifdef XLIB_RELEASE_4_OR_LATER
     _XDefaultIOError (d);
-#else
-    _XIOError (d);
-#endif
     exit (1);         /* In case the default handler doesn't exit() */
     /*NOTREACHED*/
 }
