@@ -1,9 +1,5 @@
 #include "xlib.h"
 
-#ifndef XLIB_RELEASE_4_OR_LATER
-extern XPeekEvent(), XNextEvent(), XIfEvent(), XPeekIfEvent();
-#endif
-
 #define MAX_ARGS 14
 
 static Object Argl, Argv;
