@@ -1,8 +1,6 @@
 #include "xt.h"
 
-#ifdef XT_RELEASE_4_OR_LATER
-#  include <X11/Xaw/Simple.h>
-#endif
+#include <X11/Xaw/Simple.h>
 
 #define MAX_CLASS	        128
 #define MAX_CALLBACK_PER_CLASS   10
@@ -128,9 +126,7 @@ Define_Class (name, class, r, nr) char *name; WidgetClass class;
     Error_Tag = "define-class";
     if (clast == ctab+MAX_CLASS)
 	Primitive_Error ("too many widget classes");
-#ifdef XT_RELEASE_4_OR_LATER
     XtInitializeWidgetClass (class);
-#endif
     clast->name = name;
     clast->class = class;
     clast->cb[0].name = XtNdestroyCallback;
@@ -205,9 +201,7 @@ init_xt_class () {
     /*
      * Doesn't work with Motif-1.1:
      *
-#ifdef XT_RELEASE_4_OR_LATER
     Define_Class ("simple", simpleWidgetClass, (XtResourceList)0, 0);
-#endif
      */
     Define_Class ("core", widgetClass, (XtResourceList)0, 0);
     Define_Class ("constraint", constraintWidgetClass, (XtResourceList)0, 0);
