@@ -3,7 +3,7 @@
 
 Generic_Predicate (Identifier);
 
-static Object Identifier_Equal (x, y) Object x, y; {
+static Identifier_Equal (x, y) Object x, y; {
     register struct S_Identifier *p = IDENTIFIER(x), *q = IDENTIFIER(y);
     return p->type == q->type && p->val == q->val && !p->free && !q->free;
 }
