@@ -1,8 +1,10 @@
 /* ECOFF support written by George Hartzell
+ * MACH-O support based on code by Chris Maeda (cmaeda@cs.cmu.edu)
  */
 
 #include "scheme.h"
 
+#ifdef CAN_LOAD_OBJ
 #ifdef COFF
 #  include <filehdr.h>
 #  include <syms.h>
@@ -17,19 +19,20 @@
 #  include <scnhdr.h>
 #  include <syms.h>
 #else
+#ifdef MACH_O
+#  include <rld.h>
+#else
 #  include <a.out.h>
 #  include <sys/types.h>
 #endif
 #endif
+#endif
+#endif
 
 static Object V_Load_Path, V_Load_Noisilyp, V_Load_Libraries;
 
 #ifdef CAN_LOAD_OBJ
-#  ifdef gcc
-#    define Default_Load_Libraries "/usr/new/ghs/lib/libc.a"
-#  else
-#    define Default_Load_Libraries "-lc"
-#  endif
+#  define Default_Load_Libraries "-lc"
 #else
 #  define Default_Load_Libraries ""
 #endif
@@ -109,6 +112,45 @@ Load_Source (port) Object port; {
 }
 
 #ifdef CAN_LOAD_OBJ
+
+#ifdef MACH_O
+Load_Object (port, fn) Object port; register struct S_String *fn; {
+    long retval;
+    struct mach_header *hdr;
+    char *object_filenames[2];
+    NXStream *err_stream;
+
+    P_Close_Port (port);
+
+    Disable_Interrupts;
+    /* Construct a stream for error logging:
+     */
+    if ((err_stream = NXOpenFile (fileno (stderr), NX_WRITEONLY)) == 0)
+	Primitive_Error ("NXOpenFile failed");
+
+    object_filenames[0] = fn->data;
+    object_filenames[1] = 0;
+
+    retval = rld_load (err_stream, /* report error messages here */
+	&hdr,                      /* return header address here */
+	object_filenames,          /* load these */
+	"/dev/null");              /* doesn't work if NULL?! */
+    NXClose (err_stream);
+    if (retval != 1)
+	Primitive_Error ("rld_load() failed");
+
+    /* Grab the symbol table from the just-loaded file:
+     */
+    if (The_Symbols)
+	Free_Symbols (The_Symbols);
+    The_Symbols = Snarf_Symbols (hdr);
+    if (!Call_Initializers (The_Symbols, 0))
+	Primitive_Error ("no initializers");
+    Enable_Interrupts;
+}
+
+#else /* MACH_O */
+
 Load_Object (port, fn) Object port; register struct S_String *fn; {
 #ifdef ECOFF
     struct headers hdr;
@@ -155,9 +197,13 @@ Load_Object (port, fn) Object port; register struct S_String *fn; {
 #else
 #ifdef hp9000s300
     sprintf (buf, "/bin/ld -N -x -A %s -R %x %.*s -o %s %.*s",
+#else
+#ifdef USE_GNULD
+    sprintf (buf, "/usr/local/lib/gcc-ld -N -x -A %s -T %x %.*s -o %s %.*s",
 #else
     sprintf (buf, "/bin/ld -N -x -A %s -T %x %.*s -o %s %.*s",
 #endif
+#endif
 #endif
 	li, brk, fn->size, fn->data, Loader_Output, n, lp);
     if (Verbose)
@@ -219,4 +265,6 @@ Finit_Load () {
     if (Loader_Input[0])
 	(void)unlink (Loader_Input);
 }
-#endif
+#endif /* MACH_O */
+
+#endif /* CAN_LOAD_OBJ */
