@@ -173,7 +173,7 @@ Get_Stack_Limit () {
     Max_Stack -= STACK_MARGIN;
 }
 
-#ifdef CAN_LOAD_OBJ
+#if defined(CAN_LOAD_OBJ) && !defined(MACH_O)
 exit (n) {
     Finit_Load ();
     _cleanup ();
